define(
//begin v1.x content
({
	widgetLabel: "Kontrollera stavning",
	unfound: "Hittades inte",
	skip: "Hoppa över",
	skipAll: "Hoppa över alla",
	toDic: "Lägg till i ordlistan",
	suggestions: "Förslag",
	replace: "Ersätt",
	replaceWith: "Ersätt med",
	replaceAll: "Ersätt alla",
	cancel: "Avbryt",
	msg: "Inga stavfel hittades",
	iSkip: "Hoppa över",
	iSkipAll: "Hoppa över alla liknande",
	iMsg: "Inga stavningsförslag"
})

//end v1.x content
);
